 syntax="proto3";
 package
// metamodel_version: 1.7.0
// version: 4.3.4
// A region (or regions) of a chromatinized genome that has been measured to be more accessible to an enzyme such as DNase-I or Tn5 Transpose
message AccessibleDnaRegion
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  biologicalSequence hasBiologicalSequence = 0
 }
// An activity is something that occurs over a period of time and acts upon or with entities; it may include consuming, processing, transforming, modifying, relocating, using, or generating entities.
message Activity
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
// person, group, organization or project that provides a piece of information (i.e. a knowledge association)
message Agent
 {
  iriType iri = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  uriorcurie affiliation = 0
  string address = 0
  string id = 0
  labelType name = 0
 }
// A subcellular location, cell type or gross anatomical part
message AnatomicalEntity
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// A relationship between two anatomical entities where the relationship is ontogenic, i.e. the two entities are related by development. A number of different relationship types can be used to specify the precise nature of the relationship.
message AnatomicalEntityToAnatomicalEntityOntogenicAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  anatomicalEntity subject = 0
  anatomicalEntity object = 0
  predicateType predicate = 0
 }
// A relationship between two anatomical entities where the relationship is mereological, i.e the two entities are related by parthood. This includes relationships between cellular components and cells, between cells and tissues, tissues and whole organisms
message AnatomicalEntityToAnatomicalEntityPartOfAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  anatomicalEntity subject = 0
  anatomicalEntity object = 0
  predicateType predicate = 0
 }
// a piece of writing on a particular topic presented as a stand-alone section of a larger publication
message Article
 {
  iriType iri = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 repeated  agent authors = 0
 repeated  string pages = 0
  string summary = 0
 repeated  string keywords = 0
 repeated  uriorcurie meshTerms = 0
 repeated  uriorcurie xref = 0
 repeated  string publicationType = 0
  string id = 0
  labelType name = 0
  uriorcurie publishedIn = 0
  string isoAbbreviation = 0
  string volume = 0
  string issue = 0
 }
// A typed association between two entities, supported by evidence
message Association
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
 }
// A property or characteristic of an entity. For example, an apple may have properties such as color, shape, age, crispiness. An environmental sample may have attributes such as depth, lat, long, material.
message Attribute
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// A member of a group of unicellular microorganisms lacking a nuclear membrane, that reproduce by binary fission and are often motile.
message Bacterium
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
message Behavior
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  namedThing hasInput = 0
 repeated  namedThing hasOutput = 0
 repeated  physicalEntity enabledBy = 0
 }
// An association between an mixture behavior and a behavioral feature manifested by the individual exhibited or has exhibited the behavior.
message BehaviorToBehavioralFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  behavior subject = 0
  behavioralFeature object = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
 }
// A behavioral exposure is a factor relating to behavior impacting an individual.
message BehavioralExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 }
// A phenotypic feature which is behavioral in nature.
message BehavioralFeature
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  geneticInheritance inheritance = 0
 }
// One or more causally connected executions of molecular functions
message BiologicalProcess
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  namedThing hasInput = 0
 repeated  namedThing hasOutput = 0
 repeated  physicalEntity enabledBy = 0
 }
// Either an individual molecular activity, or a collection of causally connected molecular activities in a biological system.
message BiologicalProcessOrActivity
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  namedThing hasInput = 0
 repeated  namedThing hasOutput = 0
 repeated  physicalEntity enabledBy = 0
 }
// An association between a biological process or activity and an anatomical entity.
message BiologicalProcessOrActivityToAnatomicalEntityAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  biologicalProcessOrActivity subject = 0
  anatomicalEntity object = 0
 }
// Classification relationship between biological processes or activities (e.g. coupling of two molecular activities;  assignment of molecular activity to a pathway; implicating a pathway in a biological process; etc.)
message BiologicalProcessOrActivityToBiologicalProcessOrActivityAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  biologicalProcessOrActivity subject = 0
  biologicalProcessOrActivity object = 0
  predicateType predicate = 0
 }
// Relationship between a biological processor activity (e.g. molecular activity, biological process or pathway) to gene or gene product or gene family.
message BiologicalProcessOrActivityToGeneOrGeneProductOrGeneFamilyAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  biologicalProcessOrActivity subject = 0
  geneOrGeneProductOrGeneFamily object = 0
  predicateType predicate = 0
 }
message BiologicalSex
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// An external biotic exposure is an intake of (sometimes pathological) biological organisms (including viruses).
message BioticExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 }
// This class may rarely be instantiated except if use cases of a given knowledge graph support its utility.
message Book
 {
  iriType iri = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 repeated  agent authors = 0
 repeated  string pages = 0
  string summary = 0
 repeated  string keywords = 0
 repeated  uriorcurie meshTerms = 0
 repeated  uriorcurie xref = 0
 repeated  string publicationType = 0
  labelType name = 0
  string id = 0
 repeated  string type = 0
 }
message BookChapter
 {
  iriType iri = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 repeated  agent authors = 0
 repeated  string pages = 0
  string summary = 0
 repeated  string keywords = 0
 repeated  uriorcurie meshTerms = 0
 repeated  uriorcurie xref = 0
 repeated  string publicationType = 0
  string id = 0
  labelType name = 0
  uriorcurie publishedIn = 0
  string volume = 0
  string chapter = 0
 }
// An individual (human) organism that has a patient role in some clinical context.
message Case
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
  biologicalSex hasBiologicalSex = 0
 }
// An association between a Case (patient) and a Disease
message CaseToDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  namedThing subject = 0
  predicateType predicate = 0
  disease object = 0
  onset onsetQualifier = 0
 }
// Association between a Case and a Gene (e.g., indicating a gene of interest for the case)
message CaseToGeneAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  namedThing subject = 0
  predicateType predicate = 0
  geneOrGeneProduct object = 0
 }
// An association between a case (e.g. individual patient) and a phenotypic feature in which the individual has or has had the phenotype.
message CaseToPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  predicateType predicate = 0
  namedThing object = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  boolean negated = 0
  onset onsetQualifier = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
 }
// Association between a Case and a Genetic Variant
message CaseToVariantAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  namedThing subject = 0
  predicateType predicate = 0
  sequenceVariant object = 0
  zygosity hasZygosity = 0
 }
message CausalGeneToDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum subjectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum subjectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string allelicRequirement = 0
  predicateType predicate = 0
  frequencyValue frequencyQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
  geneOrGeneProduct subject = 0
  disease object = 0
 }
message Cell
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
message CellLine
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
message CellLineAsAModelOfDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  disease diseaseContextQualifier = 0
  uriorcurie subjectSpecializationQualifier = 0
  uriorcurie objectSpecializationQualifier = 0
  string anatomicalContextQualifier = 0
  cellLine subject = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
 }
// An relationship between a cell line and a disease or a phenotype, where the cell line is derived from an individual with that disease or phenotype.
message CellLineToDiseaseOrPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  diseaseOrPhenotypicFeature subject = 0
  disease diseaseContextQualifier = 0
  uriorcurie subjectSpecializationQualifier = 0
  uriorcurie objectSpecializationQualifier = 0
  string anatomicalContextQualifier = 0
 }
// A location in or around a cell
message CellularComponent
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
message CellularOrganism
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// Describes an effect that a chemical has on a biological entity (e.g. an impact of on its abundance, activity,localization, processing, expression, etc.)
message ChemicalAffectsBiologicalEntityAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum subjectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalPartQualifierEnum subjectPartQualifier = 0
  chemicalEntityDerivativeEnum subjectDerivativeQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum subjectAspectQualifier = 0
  anatomicalEntity subjectContextQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum objectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalPartQualifierEnum objectPartQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum objectAspectQualifier = 0
  anatomicalEntity objectContextQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  causalMechanismQualifierEnum causalMechanismQualifier = 0
  anatomicalEntity anatomicalContextQualifier = 0
  string qualifiedPredicate = 0
  organismTaxon speciesContextQualifier = 0
  chemicalEntity subject = 0
  predicateType predicate = 0
  biologicalEntity object = 0
 }
// Describes an effect that a chemical has on a gene or gene product (e.g. an impact of on its abundance, activity,localization, processing, expression, etc.)
message ChemicalAffectsGeneAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum subjectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalPartQualifierEnum subjectPartQualifier = 0
  chemicalEntityDerivativeEnum subjectDerivativeQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum subjectAspectQualifier = 0
  anatomicalEntity subjectContextQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum objectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalPartQualifierEnum objectPartQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum objectAspectQualifier = 0
  anatomicalEntity objectContextQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  causalMechanismQualifierEnum causalMechanismQualifier = 0
  anatomicalEntity anatomicalContextQualifier = 0
  string qualifiedPredicate = 0
  organismTaxon speciesContextQualifier = 0
  chemicalEntity subject = 0
  predicateType predicate = 0
  biologicalEntity object = 0
 }
// A chemical entity is a physical entity that pertains to chemistry or biochemistry.
message ChemicalEntity
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string tradeName = 0
 repeated  drugAvailabilityEnum availableFrom = 0
  string maxToleratedDose = 0
  boolean isToxic = 0
 repeated  chemicalRole hasChemicalRole = 0
 }
message ChemicalEntityAssessesNamedThingAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalEntity subject = 0
  namedThing object = 0
  predicateType predicate = 0
 }
// A regulatory relationship between two genes
message ChemicalEntityOrGeneOrGeneProductRegulatesGeneAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  directionQualifierEnum objectDirectionQualifier = 0
  predicateType predicate = 0
  chemicalEntityOrGeneOrGeneProduct subject = 0
  geneOrGeneProduct object = 0
 }
// A chemical exposure is an intake of a particular chemical entity.
message ChemicalExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 repeated  quantityValue hasQuantitativeValue = 0
 }
// describes an interaction between a chemical entity and a gene or gene product. Any biological or chemical effect resulting from such an interaction are out of scope, and covered by the ChemicalAffectsGeneAssociation type (e.g. impact of a chemical on the abundance, activity, structure, etc, of either participant in the interaction)
message ChemicalGeneInteractionAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum subjectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalPartQualifierEnum subjectPartQualifier = 0
  chemicalEntityDerivativeEnum subjectDerivativeQualifier = 0
  anatomicalEntity subjectContextQualifier = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum objectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalPartQualifierEnum objectPartQualifier = 0
  anatomicalEntity objectContextQualifier = 0
  anatomicalEntity anatomicalContextQualifier = 0
  chemicalEntity subject = 0
  geneOrGeneProduct object = 0
  predicateType predicate = 0
 }
// A chemical mixture is a chemical entity composed of two or more molecular entities.
message ChemicalMixture
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string tradeName = 0
 repeated  drugAvailabilityEnum availableFrom = 0
  string maxToleratedDose = 0
  boolean isToxic = 0
 repeated  chemicalRole hasChemicalRole = 0
  string isSupplement = 0
  approvalStatusEnum highestFDAApprovalStatus = 0
  approvalStatusEnum drugRegulatoryStatusWorldWide = 0
 repeated  drugDeliveryEnum routesOfDelivery = 0
 }
// This association defines a relationship between a chemical or treatment (or procedure) and a disease or phenotypic feature where the disesae or phenotypic feature is a secondary, typically (but not always) undesirable effect.
message ChemicalOrDrugOrTreatmentSideEffectDiseaseOrPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  fDAIDAAdverseEventEnum fDAAdverseEventLevel = 0
  disease diseaseContextQualifier = 0
  uriorcurie subjectSpecializationQualifier = 0
  uriorcurie objectSpecializationQualifier = 0
  string anatomicalContextQualifier = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  predicateType predicate = 0
 }
// This association defines a relationship between a chemical or treatment (or procedure) and a disease or phenotypic feature where the disease or phenotypic feature is a secondary undesirable effect.
message ChemicalOrDrugOrTreatmentToDiseaseOrPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  fDAIDAAdverseEventEnum fDAAdverseEventLevel = 0
  predicateType predicate = 0
  disease diseaseContextQualifier = 0
  uriorcurie subjectSpecializationQualifier = 0
  uriorcurie objectSpecializationQualifier = 0
  string anatomicalContextQualifier = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
 }
// A role played by the molecular entity or part thereof within a chemical context.
message ChemicalRole
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// A relationship between two chemical entities. This can encompass actual interactions as well as temporal causal edges, e.g. one chemical converted to another.
message ChemicalToChemicalAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  namedThing subject = 0
  predicateType predicate = 0
  chemicalEntity object = 0
  organismTaxon speciesContextQualifier = 0
 }
// A causal relationship between two chemical entities, where the subject represents the upstream entity and the object represents the downstream. For any such association there is an implicit reaction: IF R has-input C1 AND R has-output C2 AND R enabled-by P AND R type Reaction THEN C1 derives-into C2 catalyst qualifier P
message ChemicalToChemicalDerivationAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  organismTaxon speciesContextQualifier = 0
 repeated  macromolecularMachineMixin catalystQualifier = 0
  chemicalEntity subject = 0
  chemicalEntity object = 0
  predicateType predicate = 0
 }
// An interaction between a chemical entity and a phenotype or disease, where the presence of the chemical gives rise to or exacerbates the phenotype.
message ChemicalToDiseaseOrPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  diseaseOrPhenotypicFeature object = 0
  disease diseaseContextQualifier = 0
  uriorcurie subjectSpecializationQualifier = 0
  uriorcurie objectSpecializationQualifier = 0
  string anatomicalContextQualifier = 0
 }
// An interaction between a chemical entity and a biological process or pathway.
message ChemicalToPathwayAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalEntity subject = 0
  pathway object = 0
 }
// A result of a chi squared analysis.
message ChiSquaredAnalysisResult
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 }
// Attributes relating to a clinical manifestation
message ClinicalAttribute
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// The course a disease typically takes from its onset, progression in time, and eventual resolution or death of the affected individual
message ClinicalCourse
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// Any entity or process that exists in the clinical domain and outside the biological realm. Diseases are placed under biological entities
message ClinicalEntity
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
// this category is currently considered broad enough to tag clinical lab measurements and other biological attributes taken as 'clinical traits' with some statistical score, for example, a p value in genetic associations.
message ClinicalFinding
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  geneticInheritance inheritance = 0
 repeated  clinicalAttribute hasAttribute = 0
 }
message ClinicalIntervention
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
// A clinical measurement is a special kind of attribute which results from a laboratory observation from a subject individual or sample. Measurements can be connected to their subject by the 'has attribute' slot.
message ClinicalMeasurement
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
  ontologyClass hasAttributeType = 0
 }
// Used to characterize and specify the phenotypic abnormalities defined in the phenotypic abnormality sub-ontology, with respect to severity, laterality, and other aspects
message ClinicalModifier
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// A clinical trial is a research study that prospectively assigns human participants or groups of humans to one or more health-related interventions to evaluate the effects on health outcomes.
message ClinicalTrial
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  studyResult hasStudyResults = 0
  researchPhaseEnum clinicalTrialPhase = 0
  string clinicalTrialPrimaryPurpose = 0
  string clinicalTrialInterventionModel = 0
  clinicalTrialStatusEnum clinicalTrialOverallStatus = 0
  string clinicalTrialBriefTitle = 0
  string clinicalTrialEnrollmentType = 0
  date clinicalTrialStartDate = 0
  integer clinicalTrialEnrollment = 0
  clinicalTrialAgeStageEnum clinicalTrialAgeStage = 0
  string clinicalTrialAgeRange = 0
  string clinicalTrialTestedIntervention = 0
 repeated  clinicalIntervention clinicalTrialInterventions = 0
 repeated  diseaseOrPhenotypicFeature clinicalTrialConditions = 0
  date creationDate = 0
 }
message CodingSequence
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  biologicalSequence hasBiologicalSequence = 0
 }
// A group of people banded together or treated as a group who share common characteristics. A cohort 'study' is a particular form of longitudinal study that samples a cohort, performing a cross-section at intervals through time.
message Cohort
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// A Common Data Element (CDE) is a standardized, precisely defined question, paired with a set of allowable responses, used systematically across different sites, studies, or clinical trials to ensure consistent data collection. Multiple CDEs (from one or more Collections) can be curated into Forms. (https://cde.nlm.nih.gov/home)
message CommonDataElement
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 }
// A complex chemical exposure is an intake of a chemical mixture (e.g. gasoline), other than a drug.
message ComplexChemicalExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 }
// A complex molecular mixture is a chemical mixture composed of two or more molecular entities with unknown concentration and stoichiometry.
message ComplexMolecularMixture
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string tradeName = 0
 repeated  drugAvailabilityEnum availableFrom = 0
  string maxToleratedDose = 0
  boolean isToxic = 0
 repeated  chemicalRole hasChemicalRole = 0
  string isSupplement = 0
  approvalStatusEnum highestFDAApprovalStatus = 0
  approvalStatusEnum drugRegulatoryStatusWorldWide = 0
 repeated  drugDeliveryEnum routesOfDelivery = 0
 }
// A result of a concept count analysis.
message ConceptCountAnalysisResult
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 }
// Level of confidence in a statement
message ConfidenceLevel
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 }
// Any association between an entity (such as a publication) and various agents that contribute to its realisation
message ContributorAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  informationContentEntity subject = 0
  predicateType predicate = 0
  agent object = 0
 repeated  ontologyClass qualifiers = 0
 }
message CorrelatedGeneToDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum subjectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum subjectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string allelicRequirement = 0
  frequencyValue frequencyQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
  float zScore = 0
  geneOrGeneProduct subject = 0
  disease object = 0
  predicateType predicate = 0
 }
// an item that refers to a collection of data from a data source.
message Dataset
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 }
// an item that holds distribution level information about a dataset.
message DatasetDistribution
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
  string distributionDownloadUrl = 0
 }
// an item that holds summary level information about a dataset.
message DatasetSummary
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
  string sourceWebPage = 0
  string sourceLogo = 0
 }
// an item that holds version level information about a dataset.
message DatasetVersion
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
  dataset hasDataset = 0
  string ingestDate = 0
  datasetDistribution hasDistribution = 0
 }
// A thing made or adapted for a particular purpose, especially a piece of mechanical or electronic equipment
message Device
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
// A device or substance used to help diagnose disease or injury
message DiagnosticAid
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
// A disorder of structure or function, especially one that produces specific signs, phenotypes or symptoms or that affects a specific location and is not simply a direct result of physical injury.  A disposition to undergo pathological processes that exists in an organism because of one or more disorders in that organism.
message Disease
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  geneticInheritance inheritance = 0
 }
// A statistical association between a disease and a chemical entity where the chemical entity has a therapeutic or adverse effect on the disease progression, symptoms or outcomes in a patient, cell line, or any model system.
message DiseaseAssociatedWithResponseToChemicalEntityAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  responseEnum responseContextQualifier = 0
  responseTargetEnum responseTargetContextQualifier = 0
  disease subject = 0
  chemicalEntity object = 0
  predicateType predicate = 0
 }
// Either one of a disease or an individual phenotypic feature. Some knowledge resources such as Monarch treat these as distinct, others such as MESH conflate.  Please see definitions of phenotypic feature and disease in this model for their independent descriptions.  This class is helpful to enforce domains and ranges that may involve either a disease or a phenotypic feature.
message DiseaseOrPhenotypicFeature
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  geneticInheritance inheritance = 0
 }
// A disease or phenotypic feature state, when viewed as an exposure, represents an precondition, leading to or influencing an outcome, e.g. HIV predisposing an individual to infections; a relative deficiency of skin pigmentation predisposing an individual to skin cancer.
message DiseaseOrPhenotypicFeatureExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 }
// An association between either a disease or a phenotypic feature and its mode of (genetic) inheritance.
message DiseaseOrPhenotypicFeatureToGeneticInheritanceAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  predicateType predicate = 0
  geneticInheritance object = 0
 }
// An association between either a disease or a phenotypic feature and an anatomical entity, where the disease/feature manifests in that site.
message DiseaseOrPhenotypicFeatureToLocationAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  anatomicalEntity object = 0
 }
// An association between an exposure event and a disease.
message DiseaseToExposureEventAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
 }
// An association between a disease and a phenotypic feature in which the phenotypic feature is associated with the disease in some way.
message DiseaseToPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  onset onsetQualifier = 0
  disease subject = 0
  phenotypicFeature object = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
 }
// A substance intended for use in the diagnosis, cure, mitigation, treatment, or prevention of disease
message Drug
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string tradeName = 0
 repeated  drugAvailabilityEnum availableFrom = 0
  string maxToleratedDose = 0
  boolean isToxic = 0
 repeated  chemicalRole hasChemicalRole = 0
  string isSupplement = 0
  approvalStatusEnum highestFDAApprovalStatus = 0
  approvalStatusEnum drugRegulatoryStatusWorldWide = 0
 repeated  drugDeliveryEnum routesOfDelivery = 0
 }
// A drug exposure is an intake of a particular drug.
message DrugExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 repeated  quantityValue hasQuantitativeValue = 0
 }
// a document accompanying a drug or its container that provides written, printed or graphic information about the drug, including drug contents, specific instructions or warnings for administration, storage and disposal instructions, etc.
message DrugLabel
 {
  iriType iri = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 repeated  agent authors = 0
 repeated  string pages = 0
  string summary = 0
 repeated  string keywords = 0
 repeated  uriorcurie meshTerms = 0
 repeated  uriorcurie xref = 0
 repeated  string publicationType = 0
  string id = 0
  labelType name = 0
 }
// An interaction between a drug and a gene or gene product.
message DrugToGeneAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  geneOrGeneProduct object = 0
 }
// drug to gene interaction exposure is a drug exposure is where the interactions of the drug with specific genes are known to constitute an 'exposure' to the organism, leading to or influencing an outcome.
message DrugToGeneInteractionExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 repeated  quantityValue hasQuantitativeValue = 0
 repeated  gene hasGeneOrGeneProduct = 0
 }
message DruggableGeneToDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum subjectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum subjectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string allelicRequirement = 0
  frequencyValue frequencyQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
  disease object = 0
  geneOrGeneProduct subject = 0
  predicateType predicate = 0
 repeated  druggableGeneCategoryEnum hasEvidence = 0
 }
message EntityToDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  clinicalApprovalStatusEnum clinicalApprovalStatus = 0
  researchPhaseEnum maxResearchPhase = 0
 }
message EntityToPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  clinicalApprovalStatusEnum clinicalApprovalStatus = 0
  researchPhaseEnum maxResearchPhase = 0
 }
// A environmental exposure is a factor relating to abiotic processes in the environment including sunlight (UV-B), atmospheric (heat, cold, general pollution) and water-born contaminants.
message EnvironmentalExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 }
message EnvironmentalFeature
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
message EnvironmentalFoodContaminant
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string tradeName = 0
 repeated  drugAvailabilityEnum availableFrom = 0
  string maxToleratedDose = 0
  boolean isToxic = 0
 repeated  chemicalRole hasChemicalRole = 0
 }
message EnvironmentalProcess
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
// Something that happens at a given place and time.
message Event
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
// Class of evidence that supports an association
message EvidenceType
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 }
// A region of the transcript sequence within a gene which is not removed from the primary RNA transcript by RNA splicing.
message Exon
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// A transcript is formed from multiple exons
message ExonToTranscriptRelationship
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  exon subject = 0
  transcript object = 0
 }
// A (possibly time bounded) incidence of a feature of the environment of an organism that influences one or more phenotypic features of that organism, potentially mediated by genes
message ExposureEvent
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 }
// An association between an exposure event and an outcome.
message ExposureEventToOutcomeAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  populationOfIndividualOrganisms populationContextQualifier = 0
  timeType temporalContextQualifier = 0
 }
// Any association between an environment and a phenotypic feature, where being in the environment influences the phenotype.
message ExposureEventToPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  exposureEvent subject = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
 }
// A substance consumed by a living organism as a source of nutrition
message Food
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string tradeName = 0
 repeated  drugAvailabilityEnum availableFrom = 0
  string maxToleratedDose = 0
  boolean isToxic = 0
 repeated  chemicalRole hasChemicalRole = 0
  string isSupplement = 0
  approvalStatusEnum highestFDAApprovalStatus = 0
  approvalStatusEnum drugRegulatoryStatusWorldWide = 0
 repeated  drugDeliveryEnum routesOfDelivery = 0
 }
message FoodAdditive
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string tradeName = 0
 repeated  drugAvailabilityEnum availableFrom = 0
  string maxToleratedDose = 0
  boolean isToxic = 0
 repeated  chemicalRole hasChemicalRole = 0
 }
// An association between a macromolecular machine mixin (gene, gene product or complex of gene products) and either a molecular activity, a biological process or a cellular location in which a function is executed.
message FunctionalAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  macromolecularMachineMixin subject = 0
  ontologyClass object = 0
 }
// A kingdom of eukaryotic, heterotrophic organisms that live as saprobes or parasites, including mushrooms, yeasts, smuts, molds, etc. They reproduce either sexually or asexually, and have life cycles that range from simple to complex. Filamentous fungi refer to those that grow as multicellular colonies (mushrooms and molds).
message Fungus
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// A region (or regions) that includes all of the sequence elements necessary to encode a functional transcript. A gene locus may include regulatory regions, transcribed regions and/or other functional sequence regions.
message Gene
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  string symbol = 0
 repeated  uriorcurie xref = 0
  biologicalSequence hasBiologicalSequence = 0
 }
// Describes an effect that a gene or gene product has on a chemical entity (e.g. an impact of on its abundance, activity, localization, processing, transport, etc.)
message GeneAffectsChemicalAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum subjectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalPartQualifierEnum subjectPartQualifier = 0
  string subjectDerivativeQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum subjectAspectQualifier = 0
  anatomicalEntity subjectContextQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum objectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalPartQualifierEnum objectPartQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum objectAspectQualifier = 0
  anatomicalEntity objectContextQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  chemicalEntityDerivativeEnum objectDerivativeQualifier = 0
  causalMechanismQualifierEnum causalMechanismQualifier = 0
  anatomicalEntity anatomicalContextQualifier = 0
  string qualifiedPredicate = 0
  organismTaxon speciesContextQualifier = 0
  geneOrGeneProduct subject = 0
  predicateType predicate = 0
  chemicalEntity object = 0
 }
message GeneAsAModelOfDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum subjectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum subjectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string allelicRequirement = 0
  predicateType predicate = 0
  frequencyValue frequencyQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
  disease object = 0
  geneOrGeneProduct subject = 0
 }
// any grouping of multiple genes or gene products related by common descent
message GeneFamily
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  gene hasGeneOrGeneProduct = 0
 }
// Relationship between a gene family and a contained gene or gene product or gene family.
message GeneFamilyToGeneOrGeneProductOrGeneFamilyAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  gene subject = 0
  geneFamily object = 0
  predicateType predicate = 0
 }
message GeneHasVariantThatContributesToDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  geneOrGeneProductOrChemicalEntityAspectEnum subjectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string allelicRequirement = 0
  frequencyValue frequencyQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
  string subjectFormOrVariantQualifier = 0
  geneOrGeneProduct subject = 0
  disease object = 0
  predicateType predicate = 0
 }
// An association between a gene or gene product or gene family and an anatomical entity.
message GeneOrGeneProductOrGeneFamilyToAnatomicalEntityAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  geneOrGeneProductOrGeneFamily subject = 0
  anatomicalEntity object = 0
 }
// Relationship between a gene or gene product or gene family to a specified biological process or activity (e.g. molecular activity, biological process or pathway).
message GeneOrGeneProductOrGeneFamilyToBiologicalProcessOrActivityAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  geneOrGeneProductOrGeneFamily subject = 0
  biologicalProcessOrActivity object = 0
  predicateType predicate = 0
 }
// Describes a regulatory relationship between two genes or gene products.
message GeneRegulatesGeneAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  geneOrGeneProductOrChemicalEntityAspectEnum objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  organismTaxon speciesContextQualifier = 0
  geneOrGeneProduct subject = 0
  predicateType predicate = 0
  geneOrGeneProduct object = 0
 }
message GeneToDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum subjectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum subjectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string allelicRequirement = 0
  predicateType predicate = 0
  frequencyValue frequencyQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
  geneOrGeneProduct subject = 0
  disease object = 0
 }
message GeneToDiseaseOrPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum subjectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum subjectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string allelicRequirement = 0
  geneOrGeneProduct subject = 0
  diseaseOrPhenotypicFeature object = 0
  predicateType predicate = 0
  frequencyValue frequencyQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
 }
// An association between a gene and a gene expression site, possibly qualified by stage/timing info.
message GeneToExpressionSiteAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  lifeStage stageQualifier = 0
  ontologyClass quantifierQualifier = 0
  uriorcurie objectSpecializationQualifier = 0
  geneOrGeneProduct subject = 0
  anatomicalEntity object = 0
  predicateType predicate = 0
 }
// Indicates that two genes are co-expressed, generally under the same conditions.
message GeneToGeneCoexpressionAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  geneOrGeneProduct subject = 0
  geneOrGeneProduct object = 0
  predicateType predicate = 0
  ontologyClass quantifierQualifier = 0
  anatomicalEntity expressionSite = 0
  lifeStage stageQualifier = 0
  diseaseOrPhenotypicFeature phenotypicState = 0
 }
// Set membership of a gene in a family of genes related by common evolutionary ancestry usually inferred by sequence comparisons. The genes in a given family generally share common sequence motifs which generally map onto shared gene product structure-function relationships.
message GeneToGeneFamilyAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  gene subject = 0
  geneFamily object = 0
  predicateType predicate = 0
 }
// A homology association between two genes. May be orthology (in which case the species of subject and object should differ) or paralogy (in which case the species may be the same)
message GeneToGeneHomologyAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  geneOrGeneProduct subject = 0
  predicateType predicate = 0
  geneOrGeneProduct object = 0
 }
// A gene is transcribed and potentially translated to a gene product
message GeneToGeneProductRelationship
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  gene subject = 0
  geneProductMixin object = 0
  predicateType predicate = 0
 }
message GeneToGoTermAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  gene subject = 0
  ontologyClass object = 0
 }
// An interaction between a gene or gene product and a biological process or pathway.
message GeneToPathwayAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  geneOrGeneProduct subject = 0
  pathway object = 0
 }
message GeneToPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  chemicalOrGeneOrGeneProductFormOrVariantEnum subjectFormOrVariantQualifier = 0
  geneOrGeneProductOrChemicalEntityAspectEnum subjectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string allelicRequirement = 0
  predicateType predicate = 0
  frequencyValue frequencyQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
  geneOrGeneProduct subject = 0
  phenotypicFeature object = 0
 }
// The pattern or 'mode' in which a particular genetic trait or disorder is passed from one generation to the next, e.g. autosomal dominant, autosomal recessive, etc.
message GeneticInheritance
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// A genome is the sum of genetic material within a cell or virion.
message Genome
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  biologicalSequence hasBiologicalSequence = 0
 }
// A genomic background exposure is where an individual's specific genomic background of genes, sequence variants or other pre-existing genomic conditions constitute a kind of 'exposure' to the organism, leading to or influencing an outcome.
message GenomicBackgroundExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 repeated  gene hasGeneOrGeneProduct = 0
  biologicalSequence hasBiologicalSequence = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// A relationship between a sequence feature and a nucleic acid entity it is localized to. The reference entity may be a chromosome, chromosome region or information entity such as a contig.
message GenomicSequenceLocalization
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  integer startInterbaseCoordinate = 0
  integer endInterbaseCoordinate = 0
  strandEnum genomeBuild = 0
  strandEnum strand = 0
  phaseEnum phase = 0
  nucleicAcidEntity subject = 0
  nucleicAcidEntity object = 0
  predicateType predicate = 0
 }
// An information content entity that describes a genome by specifying the total variation in genomic sequence and/or gene expression, relative to some established background
message Genotype
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  zygosity hasZygosity = 0
  biologicalSequence hasBiologicalSequence = 0
 }
message GenotypeAsAModelOfDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  predicateType predicate = 0
  namedThing object = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  genotype subject = 0
 }
message GenotypeToDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  namedThing subject = 0
  predicateType predicate = 0
  namedThing object = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
 }
// Any association between a genotype and a gene. The genotype have have multiple variants in that gene or a single one. There is no assumption of cardinality
message GenotypeToGeneAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  predicateType predicate = 0
  genotype subject = 0
  gene object = 0
 }
// Any association between one genotype and a genotypic entity that is a sub-component of it
message GenotypeToGenotypePartAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  predicateType predicate = 0
  genotype subject = 0
  genotype object = 0
 }
// Any association between one genotype and a phenotypic feature, where having the genotype confers the phenotype, either in isolation or through environment
message GenotypeToPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  predicateType predicate = 0
  genotype subject = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
 }
// Any association between a genotype and a sequence variant.
message GenotypeToVariantAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  predicateType predicate = 0
  genotype subject = 0
  sequenceVariant object = 0
 }
// An attribute corresponding to the genotypic sex of the individual, based upon genotypic composition of sex chromosomes.
message GenotypicSex
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// A geographic exposure is a factor relating to geographic proximity to some impactful entity.
message GeographicExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 }
// a location that can be described in lat/long coordinates
message GeographicLocation
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  float latitude = 0
  float longitude = 0
 }
// a location that can be described in lat/long coordinates, for a particular time
message GeographicLocationAtTime
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  float latitude = 0
  float longitude = 0
  timeType timepoint = 0
 }
message GrossAnatomicalStructure
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// A set of zero or more Alleles on a single instance of a Sequence[VMC]
message Haplotype
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  biologicalSequence hasBiologicalSequence = 0
 }
message Hospitalization
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
// A member of the the species Homo sapiens.
message Human
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// A study result that represents a result, from a supporting Study, which is specifically associated with an Integrated Clinical and Environmental Exposures Service (ICEES) knowledge assertion.
message IceesStudyResult
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
  float chiSquaredStatistic = 0
  integer chiSquaredDof = 0
  float chiSquaredP = 0
  integer totalSampleSize = 0
  float fisherExactOddsRatio = 0
  float fisherExactP = 0
  float logOddsRatio = 0
 repeated  float logOddsRatio95Ci = 0
 }
// An instance of an organism. For example, Richard Nixon, Charles Darwin, my pet cat. Example ID: ORCID:0000-0002-5355-2576
message IndividualOrganism
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// association between a named thing and a information content entity where the specific context of the relationship between that named thing and the publication is unknown. For example, model organisms databases often capture the knowledge that a gene is found in a journal article, but not specifically the context in which that gene was documented in the article. In these cases, this association with the accompanying predicate 'mentions' could be used. Conversely, for more specific associations (like 'gene to disease association', the publication should be captured as an edge property).
message InformationContentEntityToNamedThingAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  namedThing subject = 0
  namedThing object = 0
  predicateType predicate = 0
 }
// An animal lacking a vertebral column. This group consists of 98% of all animal species.
message Invertebrate
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// an article, typically presenting results of research, that is published in an issue of a scientific journal.
message JournalArticle
 {
  iriType iri = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 repeated  agent authors = 0
 repeated  string pages = 0
  string summary = 0
 repeated  string keywords = 0
 repeated  uriorcurie meshTerms = 0
 repeated  uriorcurie xref = 0
 repeated  string publicationType = 0
  string id = 0
  labelType name = 0
  uriorcurie publishedIn = 0
  string isoAbbreviation = 0
  string volume = 0
  string issue = 0
 }
// A knowledge graph represented in KGX format
message KnowledgeGraph
 {
 repeated  entity nodes = 0
 repeated  association edges = 0
 }
// A stage of development or growth of an organism, including post-natal adult stages
message LifeStage
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// A result of a log odds ratio analysis.
message LogOddsAnalysisResult
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 }
// A stable assembly of two or more macromolecules, i.e. proteins, nucleic acids, carbohydrates or lipids, in which at least one component is a protein and the constituent parts function together.
message MacromolecularComplex
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// A functional association between a macromolecular machine (gene, gene product or complex) and a biological process or pathway (as represented in the GO biological process branch), where the entity carries out some part of the process, regulates it, or acts upstream of it.
message MacromolecularMachineToBiologicalProcessAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  macromolecularMachineMixin subject = 0
  biologicalProcess object = 0
  organismTaxon speciesContextQualifier = 0
 }
// A functional association between a macromolecular machine (gene, gene product or complex) and a cellular component (as represented in the GO cellular component branch), where the entity carries out its function in the cellular component.
message MacromolecularMachineToCellularComponentAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  macromolecularMachineMixin subject = 0
  cellularComponent object = 0
  organismTaxon speciesContextQualifier = 0
 }
// A functional association between a macromolecular machine (gene, gene product or complex) and a molecular activity (as represented in the GO molecular function branch), where the entity carries out the activity, or contributes to its execution.
message MacromolecularMachineToMolecularActivityAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  macromolecularMachineMixin subject = 0
  molecularActivity object = 0
  organismTaxon speciesContextQualifier = 0
 }
// A member of the class Mammalia, a clade of endothermic amniotes distinguished from reptiles and birds by the possession of hair, three middle ear bones, mammary glands, and a neocortex
message Mammal
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// A sample is a limited quantity of something (e.g. an individual or set of individuals from a population, or a portion of a substance) to be used for testing, analysis, inspection, investigation, demonstration, or trial use. [SIO]
message MaterialSample
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
// An association between a material sample and the material entity from which it is derived.
message MaterialSampleDerivationAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  materialSample subject = 0
  predicateType predicate = 0
  namedThing object = 0
 }
// An association between a material sample and a disease or phenotype.
message MaterialSampleToDiseaseOrPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  disease diseaseContextQualifier = 0
  uriorcurie subjectSpecializationQualifier = 0
  uriorcurie objectSpecializationQualifier = 0
  string anatomicalContextQualifier = 0
 }
message MicroRNA
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// An execution of a molecular function carried out by a gene product or macromolecular complex.
message MolecularActivity
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  molecularEntity hasInput = 0
 repeated  molecularEntity hasOutput = 0
 repeated  macromolecularMachineMixin enabledBy = 0
 }
// Added in response to capturing relationship between microbiome activities as measured via measurements of blood analytes as collected via blood and stool samples
message MolecularActivityToChemicalEntityAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  molecularActivity subject = 0
  chemicalEntity object = 0
 }
// Added in response to capturing relationship between microbiome activities as measured via measurements of blood analytes as collected via blood and stool samples
message MolecularActivityToMolecularActivityAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  molecularActivity subject = 0
  molecularActivity object = 0
 }
// Association that holds the relationship between a reaction and the pathway it participates in.
message MolecularActivityToPathwayAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  molecularActivity subject = 0
  pathway object = 0
  predicateType predicate = 0
 }
// A molecular entity is a chemical entity composed of individual or covalently bonded atoms.
message MolecularEntity
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string tradeName = 0
 repeated  drugAvailabilityEnum availableFrom = 0
  string maxToleratedDose = 0
  boolean isToxic = 0
 repeated  chemicalRole hasChemicalRole = 0
  boolean isMetabolite = 0
 }
// A molecular mixture is a chemical mixture composed of two or more molecular entities with known concentration and stoichiometry.
message MolecularMixture
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string tradeName = 0
 repeated  drugAvailabilityEnum availableFrom = 0
  string maxToleratedDose = 0
  boolean isToxic = 0
 repeated  chemicalRole hasChemicalRole = 0
  string isSupplement = 0
  approvalStatusEnum highestFDAApprovalStatus = 0
  approvalStatusEnum drugRegulatoryStatusWorldWide = 0
 repeated  drugDeliveryEnum routesOfDelivery = 0
 }
// a databased entity or concept/class
message NamedThing
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
message NamedThingAssociatedWithLikelihoodOfNamedThingAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  namedThing subject = 0
  string subjectAspectQualifier = 0
  ontologyClass subjectContextQualifier = 0
  predicateType predicate = 0
  namedThing object = 0
  string objectAspectQualifier = 0
  ontologyClass objectContextQualifier = 0
  populationOfIndividualOrganisms populationContextQualifier = 0
 }
message NoncodingRNAProduct
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// A nucleic acid entity is a molecular entity characterized by availability in gene databases of nucleotide-based sequence representations of its precise sequence; for convenience of representation, partial sequences of various kinds are included.
message NucleicAcidEntity
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string tradeName = 0
 repeated  drugAvailabilityEnum availableFrom = 0
  string maxToleratedDose = 0
  boolean isToxic = 0
 repeated  chemicalRole hasChemicalRole = 0
  boolean isMetabolite = 0
  biologicalSequence hasBiologicalSequence = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// A linear nucleotide sequence pattern that is widespread and has, or is conjectured to have, a biological significance. e.g. the TATA box promoter motif, transcription factor binding consensus sequences.
message NucleicAcidSequenceMotif
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// A chemical modification of a histone protein within a nucleosome octomer or a substitution of a histone with a variant histone isoform. e.g. Histone 4 Lysine 20 methylation (H4K20me), histone variant H2AZ substituting H2A.
message NucleosomeModification
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  biologicalSequence hasBiologicalSequence = 0
 }
// A result of a observed expected frequency analysis.
message ObservedExpectedFrequencyAnalysisResult
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 }
// The age group in which (disease) symptom manifestations appear.
message Onset
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// describes a characteristic of an organismal entity.
message OrganismAttribute
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// A classification of a set of organisms. Example instances: NCBITaxon:9606 (Homo sapiens), NCBITaxon:2 (Bacteria). Can also be used to represent strains or subspecies.
message OrganismTaxon
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  taxonomicRank hasTaxonomicRank = 0
 }
// An interaction relationship between two taxa. This may be a symbiotic relationship (encompassing mutualism and parasitism), or it may be non-symbiotic. Example: plague transmitted_by flea; cattle domesticated_by Homo sapiens; plague infects Homo sapiens
message OrganismTaxonToOrganismTaxonInteraction
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  string associatedEnvironmentalContext = 0
  organismTaxon subject = 0
  organismTaxon object = 0
  predicateType predicate = 0
 }
// A child-parent relationship between two taxa. For example: Homo sapiens subclass_of Homo
message OrganismTaxonToOrganismTaxonSpecialization
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  organismTaxon subject = 0
  organismTaxon object = 0
  predicateType predicate = 0
 }
message OrganismToOrganismAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  individualOrganism subject = 0
  individualOrganism object = 0
 }
message OrganismalEntityAsAModelOfDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  organismalEntity subject = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
 }
// An interaction between two genes or two gene products. May be physical (e.g. protein binding) or genetic (between genes). May be symmetric (e.g. protein interaction) or directed (e.g. phosphorylation)
message PairwiseGeneToGeneInteraction
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  geneOrGeneProduct subject = 0
  geneOrGeneProduct object = 0
  predicateType predicate = 0
 }
// An interaction at the molecular level between two physical entities
message PairwiseMolecularInteraction
 {
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  ontologyClass interactingMoleculesCategory = 0
  molecularEntity subject = 0
  string id = 0
  predicateType predicate = 0
  molecularEntity object = 0
 }
// a legal document granted by a patent issuing authority which confers upon the patenter the sole right to make, use and sell an invention for a set period of time.
message Patent
 {
  iriType iri = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 repeated  agent authors = 0
 repeated  string pages = 0
  string summary = 0
 repeated  string keywords = 0
 repeated  uriorcurie meshTerms = 0
 repeated  uriorcurie xref = 0
 repeated  string publicationType = 0
  string id = 0
  labelType name = 0
 }
// An abnormal anatomical structure, when viewed as an exposure, representing an precondition, leading to or influencing an outcome, e.g. thrombosis leading to an ischemic disease outcome.
message PathologicalAnatomicalExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 }
// An anatomical structure with the potential of have an abnormal or deleterious effect at the subcellular, cellular, multicellular, or organismal level.
message PathologicalAnatomicalStructure
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// A biologic function or a process having an abnormal or deleterious effect at the subcellular, cellular, multicellular, or organismal level.
message PathologicalProcess
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  namedThing hasInput = 0
 repeated  namedThing hasOutput = 0
 repeated  physicalEntity enabledBy = 0
 }
// A pathological process, when viewed as an exposure, representing a precondition, leading to or influencing an outcome, e.g. autoimmunity leading to disease.
message PathologicalProcessExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 }
message Pathway
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  namedThing hasInput = 0
 repeated  namedThing hasOutput = 0
 repeated  physicalEntity enabledBy = 0
 }
// a fact or situation that is observed to exist or happen, especially one whose cause or explanation is in question
message Phenomenon
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
// A combination of entity and quality that makes up a phenotyping statement. An observable characteristic of an individual resulting from the interaction of its genotype with its molecular and physical environment.
message PhenotypicFeature
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  geneticInheritance inheritance = 0
 }
message PhenotypicFeatureToDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  predicateType predicate = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
 }
// Association between two concept nodes of phenotypic character, qualified by the predicate used. This association may typically be used to specify 'similar_to' or 'member_of' relationships.
message PhenotypicFeatureToPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
  disease diseaseContextQualifier = 0
 }
// A property of a phenotype
message PhenotypicQuality
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// An attribute corresponding to the phenotypic sex of the individual, based upon the reproductive organs present.
message PhenotypicSex
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// An entity that has material reality (a.k.a. physical essence).
message PhysicalEntity
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
message PhysiologicalProcess
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  namedThing hasInput = 0
 repeated  namedThing hasOutput = 0
 repeated  physicalEntity enabledBy = 0
 }
// Any entity or process that exists at the level of the whole planet
message PlanetaryEntity
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
message Plant
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// A polypeptide is a molecular entity characterized by availability in protein databases of amino-acid-based sequence representations of its precise primary structure; for convenience of representation, partial sequences of various kinds are included, even if they do not represent a physical molecule.
message Polypeptide
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// A collection of individuals from the same taxonomic class distinguished by one or more characteristics.  Characteristics can include, but are not limited to, shared geographic location, genetics, phenotypes.
message PopulationOfIndividualOrganisms
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// An association between a two populations
message PopulationToPopulationAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  populationOfIndividualOrganisms subject = 0
  populationOfIndividualOrganisms object = 0
  predicateType predicate = 0
 }
// A chemical modification of a polypeptide or protein that occurs after translation. e.g. polypeptide cleavage to form separate proteins, methylation or acetylation of histone tail amino acids, protein ubiquitination.
message PosttranslationalModification
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// A deprecated predicate mapping object contains the deprecated predicate and an example of the rewiring that should be done to use a qualified statement in its place.
message PredicateMapping
 {
  string mappedPredicate = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string subjectFormOrVariantQualifier = 0
  string subjectPartQualifier = 0
  string subjectDerivativeQualifier = 0
  string subjectContextQualifier = 0
  predicateType predicate = 0
  string qualifiedPredicate = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string objectFormOrVariantQualifier = 0
  string objectPartQualifier = 0
  string objectDerivativeQualifier = 0
  string objectContextQualifier = 0
  causalMechanismQualifierEnum causalMechanismQualifier = 0
  string anatomicalContextQualifier = 0
  organismTaxon speciesContextQualifier = 0
 repeated  namedThing exactMatch = 0
 repeated  namedThing narrowMatch = 0
 repeated  namedThing broadMatch = 0
 }
// a document reresenting an early version of an author's original scholarly work, such as a research paper or a review, prior to formal peer review and publication in a peer-reviewed scholarly or scientific journal.
message PreprintPublication
 {
  iriType iri = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 repeated  agent authors = 0
 repeated  string pages = 0
  string summary = 0
 repeated  string keywords = 0
 repeated  uriorcurie meshTerms = 0
 repeated  uriorcurie xref = 0
 repeated  string publicationType = 0
  string id = 0
  labelType name = 0
 }
// A series of actions conducted in a certain order or manner
message Procedure
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 }
// Describes a regulatory relationship between two genes or gene products.
message ProcessRegulatesProcessAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  biologicalProcess subject = 0
  predicateType predicate = 0
  biologicalProcess object = 0
 }
// A chemical entity (often a mixture) processed for consumption for nutritional, medical or technical use. Is a material entity that is created or changed during material processing.
message ProcessedMaterial
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string tradeName = 0
 repeated  drugAvailabilityEnum availableFrom = 0
  string maxToleratedDose = 0
  boolean isToxic = 0
 repeated  chemicalRole hasChemicalRole = 0
  string isSupplement = 0
  approvalStatusEnum highestFDAApprovalStatus = 0
  approvalStatusEnum drugRegulatoryStatusWorldWide = 0
 repeated  drugDeliveryEnum routesOfDelivery = 0
 }
// A gene product that is composed of a chain of amino acid sequences and is produced by ribosome-mediated translation of mRNA
message Protein
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// A conserved part of protein sequence and (tertiary) structure that can evolve, function, and exist independently of the rest of the protein chain. Protein domains maintain their structure and function independently of the proteins in which they are found. e.g. an SH3 domain.
message ProteinDomain
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  gene hasGeneOrGeneProduct = 0
 }
message ProteinFamily
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  gene hasGeneOrGeneProduct = 0
 }
// Represents a protein that is a specific isoform of the canonical or reference protein. See https://www.ncbi.nlm.nih.gov/pmc/articles/PMC4114032/
message ProteinIsoform
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// Any ‘published’ piece of information. Publications are considered broadly to include any document or document part made available in print or on the web - which may include scientific journal issues, individual articles, and books - as well as things like pre-prints, white papers, patents, drug labels, web pages, protocol documents,  and even a part of a publication if of significant knowledge scope (e.g. a figure, figure legend, or section highlighted by NLP).
message Publication
 {
  iriType iri = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 repeated  agent authors = 0
 repeated  string pages = 0
  string summary = 0
 repeated  string keywords = 0
 repeated  uriorcurie meshTerms = 0
 repeated  uriorcurie xref = 0
 repeated  string publicationType = 0
  string id = 0
  labelType name = 0
 }
// A value of an attribute that is quantitative and measurable, expressed as a combination of a unit and a numeric value
message QuantityValue
 {
  unit hasUnit = 0
  double hasNumericValue = 0
 }
message ReactionToCatalystAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  predicateType predicate = 0
  organismTaxon speciesContextQualifier = 0
  integer stoichiometry = 0
  reactionDirectionEnum reactionDirection = 0
  reactionSideEnum reactionSide = 0
  molecularEntity subject = 0
  geneOrGeneProduct object = 0
 }
message ReactionToParticipantAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  predicateType predicate = 0
  chemicalEntity object = 0
  organismTaxon speciesContextQualifier = 0
  integer stoichiometry = 0
  reactionDirectionEnum reactionDirection = 0
  reactionSideEnum reactionSide = 0
  molecularEntity subject = 0
 }
// A gene altered in its expression level in the context of some experiment as a result of being targeted by gene-knockdown reagent(s) such as a morpholino or RNAi.
message ReagentTargetedGene
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  biologicalSequence hasBiologicalSequence = 0
 }
// A region (or regions) of the genome that contains known or putative regulatory elements that act in cis- or trans- to affect the transcription of gene
message RegulatoryRegion
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  biologicalSequence hasBiologicalSequence = 0
 }
// An OWL property used as an edge label
message RelationshipType
 {
  string id = 0
 }
// A result of a relative frequency analysis.
message RelativeFrequencyAnalysisResult
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 }
// Provides information about how a particular InformationResource served as a source from which knowledge expressed in an Edge, or data used to generate this knowledge, was retrieved.
message RetrievalSource
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
  uriorcurie resourceId = 0
  resourceRoleEnum resourceRole = 0
 repeated  uriorcurie upstreamResourceIds = 0
 repeated  uriorcurie sourceRecordUrls = 0
 repeated  uriorcurie xref = 0
 }
message RNAProduct
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// Represents a protein that is a specific isoform of the canonical or reference RNA
message RNAProductIsoform
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// An association between a sequence feature and a nucleic acid entity it is localized to.
message SequenceAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
 }
// For example, a particular exon is part of a particular transcript or gene
message SequenceFeatureRelationship
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  nucleicAcidEntity subject = 0
  nucleicAcidEntity object = 0
 }
// A sequence_variant is a non exact copy of a sequence_feature or genome exhibiting one or more sequence_alteration.
message SequenceVariant
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  gene hasGene = 0
 repeated  string hgvsNomenclature = 0
  biologicalSequence hasBiologicalSequence = 0
  string id = 0
 }
// This class may rarely be instantiated except if use cases of a given knowledge graph support its utility.
message Serial
 {
  iriType iri = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 repeated  agent authors = 0
 repeated  string pages = 0
  string summary = 0
 repeated  string keywords = 0
 repeated  uriorcurie meshTerms = 0
 repeated  uriorcurie xref = 0
 repeated  string publicationType = 0
  labelType name = 0
  string isoAbbreviation = 0
  string volume = 0
  string issue = 0
  string id = 0
 repeated  string type = 0
 }
// describes the severity of a phenotypic feature or disease
message SeverityValue
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// A small RNA molecule that is the product of a longer exogenous or endogenous dsRNA, which is either a bimolecular duplex or very long hairpin, processed (via the Dicer pathway) such that numerous siRNAs accumulate from both strands of the dsRNA. SRNAs trigger the cleavage of their target molecules.
message SiRNA
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// A small molecule entity is a molecular entity characterized by availability in small-molecule databases of SMILES, InChI, IUPAC, or other unambiguous representation of its precise chemical structure; for convenience of representation, any valid chemical representation is included, even if it is not strictly molecular (e.g., sodium ion).
message SmallMolecule
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string tradeName = 0
 repeated  drugAvailabilityEnum availableFrom = 0
  string maxToleratedDose = 0
  boolean isToxic = 0
 repeated  chemicalRole hasChemicalRole = 0
  boolean isMetabolite = 0
 }
// SNVs are single nucleotide positions in genomic DNA at which different sequence alternatives exist
message Snv
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  gene hasGene = 0
 repeated  string hgvsNomenclature = 0
  biologicalSequence hasBiologicalSequence = 0
  string id = 0
 }
// Attributes relating to a socioeconomic manifestation
message SocioeconomicAttribute
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
// A socioeconomic exposure is a factor relating to social and financial status of an affected individual (e.g. poverty).
message SocioeconomicExposure
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 repeated  socioeconomicAttribute hasAttribute = 0
 }
// a detailed investigation and/or analysis
message Study
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  studyResult hasStudyResults = 0
 }
// A group of people banded together or treated as a group as participants in a research study.
message StudyPopulation
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// a variable that is used as a measure in the investigation of a study
message StudyVariable
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 }
message TaxonToTaxonAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  organismTaxon subject = 0
  organismTaxon object = 0
 }
// A descriptor for the rank within a taxonomic classification. Example instance: TAXRANK:0000017 (kingdom)
message TaxonomicRank
 {
  string id = 0
 }
// A study result that represents information extracted from text using natural language processing techniques. This includes the extracted text, location offsets within the source document, confidence scores, and other metadata related to the text mining process.
message TextMiningStudyResult
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 repeated  string supportingText = 0
 repeated  integer subjectLocationInText = 0
 repeated  integer objectLocationInText = 0
  integer extractionConfidenceScore = 0
  string supportingDocumentType = 0
  integer supportingDocumentYear = 0
  string supportingTextSectionType = 0
 }
// An RNA synthesized on a DNA or RNA template by an RNA polymerase.
message Transcript
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 }
// A gene is a collection of transcripts
message TranscriptToGeneRelationship
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  transcript subject = 0
  gene object = 0
 }
// A region (or regions) of the genome that contains a region of DNA known or predicted to bind a protein that modulates gene transcription
message TranscriptionFactorBindingSite
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
  biologicalSequence hasBiologicalSequence = 0
 }
// A treatment is targeted at a disease or phenotype and may involve multiple drug 'exposures', medical devices and/or procedures
message Treatment
 {
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  timeType timepoint = 0
  string exposureType = 0
  string exposureVehicle = 0
  string exposureRoute = 0
  integer exposureStartAge = 0
  integer exposureEndAge = 0
  time exposureDuration = 0
  string exposureMagnitude = 0
  string exposureAdditionalCondition = 0
  string id = 0
 repeated  drug hasDrug = 0
 repeated  device hasDevice = 0
 repeated  procedure hasProcedure = 0
 }
message VariantAsAModelOfDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  predicateType predicate = 0
  namedThing object = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  sequenceVariant subject = 0
 }
message VariantToDiseaseAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  namedThing subject = 0
  predicateType predicate = 0
  namedThing object = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
 }
// An association between a variant and a gene, where the variant has a genetic association with the gene (i.e. is in linkage disequilibrium)
message VariantToGeneAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  gene object = 0
  predicateType predicate = 0
 }
// An association between a variant and expression of a gene (i.e. e-QTL)
message VariantToGeneExpressionAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  namedThing subject = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  gene object = 0
  predicateType predicate = 0
  ontologyClass quantifierQualifier = 0
  anatomicalEntity expressionSite = 0
  lifeStage stageQualifier = 0
  diseaseOrPhenotypicFeature phenotypicState = 0
 }
message VariantToPhenotypicFeatureAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  namedThing object = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  sequenceVariant subject = 0
  frequencyValue frequencyQualifier = 0
  string subjectAspectQualifier = 0
  directionQualifierEnum subjectDirectionQualifier = 0
  string objectAspectQualifier = 0
  directionQualifierEnum objectDirectionQualifier = 0
  string qualifiedPredicate = 0
  disease diseaseContextQualifier = 0
  biologicalSex sexQualifier = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasQuotient = 0
  double hasPercentage = 0
 }
// An association between a variant and a population, where the variant has particular frequency in the population
message VariantToPopulationAssociation
 {
  string id = 0
  iriType iri = 0
  labelType name = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
  predicateType predicate = 0
  boolean negated = 0
  string qualifier = 0
 repeated  ontologyClass qualifiers = 0
 repeated  publication publications = 0
 repeated  retrievalSource sources = 0
 repeated  evidenceType hasEvidence = 0
  string knowledgeSource = 0
  string primaryKnowledgeSource = 0
 repeated  string aggregatorKnowledgeSource = 0
  knowledgeLevelEnum knowledgeLevel = 0
  agentTypeEnum agentType = 0
  timeType timepoint = 0
  string originalSubject = 0
  uriorcurie originalPredicate = 0
  string originalObject = 0
  string subjectFeatureName = 0
  string objectFeatureName = 0
  ontologyClass subjectCategory = 0
  ontologyClass objectCategory = 0
 repeated  string subjectClosure = 0
 repeated  string objectClosure = 0
 repeated  ontologyClass subjectCategoryClosure = 0
 repeated  ontologyClass objectCategoryClosure = 0
  string subjectNamespace = 0
  string objectNamespace = 0
 repeated  string subjectLabelClosure = 0
 repeated  string objectLabelClosure = 0
 repeated  retrievalSource retrievalSourceIds = 0
  float pValue = 0
  float adjustedPValue = 0
 repeated  study hasSupportingStudies = 0
  date updateDate = 0
  float hasConfidenceScore = 0
 repeated  string type = 0
 repeated  uriorcurie category = 0
  sequenceVariant subject = 0
  populationOfIndividualOrganisms object = 0
  double hasQuotient = 0
  integer hasCount = 0
  integer hasTotal = 0
  double hasPercentage = 0
  frequencyValue frequencyQualifier = 0
 }
// A sub-phylum of animals consisting of those having a bony or cartilaginous vertebral column.
message Vertebrate
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// A virus is a microorganism that replicates itself as a microRNA and infects the host cell.
message Virus
 {
  string id = 0
  iriType iri = 0
 repeated  string type = 0
  labelType name = 0
  narrativeText description = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
 repeated  organismTaxon inTaxon = 0
  labelType inTaxonLabel = 0
 repeated  attribute hasAttribute = 0
 }
// a document that is published according to World Wide Web standards, which may incorporate text, graphics, sound, and/or other features.
message WebPage
 {
  iriType iri = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  string license = 0
  string rights = 0
  string format = 0
  date creationDate = 0
 repeated  agent authors = 0
 repeated  string pages = 0
  string summary = 0
 repeated  string keywords = 0
 repeated  uriorcurie meshTerms = 0
 repeated  uriorcurie xref = 0
 repeated  string publicationType = 0
  string id = 0
  labelType name = 0
 }
message Zygosity
 {
  string id = 0
 repeated  string type = 0
  narrativeText description = 0
 repeated  attribute hasAttribute = 0
  boolean deprecated = 0
 repeated  string providedBy = 0
 repeated  uriorcurie xref = 0
  labelType fullName = 0
 repeated  labelType synonym = 0
 repeated  uriorcurie equivalentIdentifiers = 0
  float informationContent = 0
  uriorcurie taxon = 0
 repeated  uriorcurie category = 0
  labelType name = 0
  ontologyClass hasAttributeType = 0
 repeated  quantityValue hasQuantitativeValue = 0
  namedThing hasQualitativeValue = 0
  iriType iri = 0
 }
